@@ -1330,11 +1330,14 @@ void cdrReadInterrupt() {
 				SPU_playADPCMchannel(&cdr.Xa);
 				cdr.FirstSector = 0;
 
-
+#if 0
 				// Crash Team Racing: music, speech
+				// - done using cdda decoded buffer (spu irq)
+				// - don't do here
 
 				// signal ADPCM data ready
 				psxHu32ref(0x1070) |= SWAP32((u32)0x200);
+#endif
 			}
 			else cdr.FirstSector = -1;
 		}
@@ -1897,11 +1900,10 @@ void cdrWrite3(unsigned char rt) {
 		// - Final Fantasy Tactics
 		// - various other games
 
-		/*
+		if (cdr.Irq) // rearmed guesswork hack
 		if (cdr.Reading && !cdr.ResultReady) {
 			CDREAD_INT((cdr.Mode & MODE_SPEED) ? (cdReadTime / 2) : cdReadTime);
 		}
-		*/
 
 		return;
 	}
