@@ -13,6 +13,7 @@
 
 #include "main.h"
 #include "../libpcsxcore/psemu_plugin_defs.h"
+#include "common/readpng.h"
 
 #define X_RES           800
 #define Y_RES           480
@@ -27,8 +28,9 @@ void *pl_fbdev_buf;
 int keystate;
 int g_opts=0;
 int sens,y_def;
-char *cfile;
 extern int gles;
+int pl_buf_w=0,pl_buf_h=0;
+extern char * file_name;
 
 int in_type = PSE_PAD_TYPE_STANDARD;
 int in_keystate, in_a1[2], in_a2[2];
@@ -96,11 +98,26 @@ window_key_proxy(GtkWidget *widget,
 			break;
 		case 19:
 			if (event->type == GDK_KEY_PRESS)
-				SaveState(cfile);
+	{
+				emu_save_state(state_slot);
+				
+				char buf[MAXPATHLEN];
+				sprintf (buf,"screenshots/%s.%3.3d",file_name,state_slot);
+				writepng(buf, image->mem, pl_buf_w,pl_buf_h);
+
 			return;
+	}
 		case 20:
 			if (event->type == GDK_KEY_PRESS)
-				LoadState(cfile);
+				emu_load_state(state_slot);
+			return;
+		case 21:
+			if (event->type == GDK_KEY_PRESS)
+			state_slot=(state_slot<9)?state_slot+1:0;
+			return;
+		case 22:
+			if (event->type == GDK_KEY_PRESS)
+			state_slot=(state_slot>0)?state_slot-1:8;
 			return;
 	}
 
@@ -134,7 +151,7 @@ void maemo_init(int *argc, char ***argv)
 	for (i=0;i<65536;i++)
 		keymap[i]=164;
 	if (NULL != pFile) {
-		for(i=0;i<21;i++){
+		for(i=0;i<23;i++){
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
 		}
@@ -184,6 +201,7 @@ else
 void menu_loop(void)
 {
 }
+
 void *pl_fbdev_set_mode(int w, int h, int bpp)
 {
 	if (gles!=0)return pl_fbdev_buf;
@@ -208,7 +226,7 @@ else
 				(gdouble)D_WIDTH / (gdouble)w,
 				(gdouble)D_HEIGHT / (gdouble)h
 	);
-
+ pl_buf_w=w;pl_buf_h=h;
 return pl_fbdev_buf;
 }
 void *pl_fbdev_flip(void)
@@ -277,3 +295,12 @@ const struct rearmed_cbs pl_rearmed_cbs = {
 	&UseFrameSkip,
 };
 
+void *pl_prepare_screenshot(int *w, int *h, int *bpp)
+{
+    *w = 800;
+	*h = 640;
+	*bpp=16;
+	
+	return pl_fbdev_buf;
+}
+
