@@ -10,6 +10,7 @@
 #include "gpu.h"
 
 #include "plugin_lib.h"
+#include "arm_utils.h"
 #include "pcnt.h"
 
 // misc globals
@@ -18,15 +19,8 @@ BOOL           bCheckMask = FALSE;
 unsigned short sSetMask;
 unsigned long  lSetMask;
 
-#ifndef __arm__
-#define bgr555_to_rgb565 memcpy
-#define bgr888_to_rgb888 memcpy
-#endif
-
 static void blit(void)
 {
- extern void bgr555_to_rgb565(void *dst, void *src, int bytes);
- //extern void bgr888_to_rgb888(void *dst, void *src, int bytes);
  int px = PSXDisplay.DisplayPosition.x & ~3; // XXX: align needed by bgr*_to_...
  int py = PSXDisplay.DisplayPosition.y;
  int w = PreviousPSXDisplay.Range.x1;
@@ -34,47 +28,30 @@ static void blit(void)
  int pitch = PreviousPSXDisplay.DisplayMode.x;
  unsigned short *srcs = psxVuw + py * 1024 + px;
  unsigned char *dest = pl_fbdev_buf;
- typedef unsigned long u32;
- typedef unsigned int u16;
- u32 *dest_screen32=(u32*)pl_fbdev_buf;
 
  if (w <= 0)
    return;
 
- // TODO: clear border if centering?
-
+#ifndef MAEMO
  pitch *= PSXDisplay.RGB24 ? 3 : 2;
+#else
+ // n900 doesn't do rgb24 for some reason
+ pitch *= 2;
+ #define bgr888_to_rgb888 bgr888_to_rgb565
+#endif
 
  // account for centering
-// h -= PreviousPSXDisplay.Range.y0;
+ h -= PreviousPSXDisplay.Range.y0;
  dest += PreviousPSXDisplay.Range.y0 / 2 * pitch;
  dest += (PreviousPSXDisplay.Range.x0 & ~3) * 2; // must align here too..
 
-
  if (PSXDisplay.RGB24)
  {
-   /*for (; h-- > 0; dest += pitch, srcs += 1024)
+   for (; h-- > 0; dest += pitch, srcs += 1024)
    {
      bgr888_to_rgb888(dest, srcs, w * 3);
-   }*/
-#define gp2x_video_RGB_color16(R,B,G) ((unsigned short)(((((R)&0xF8)<<8)|(((G)&0xFC)<<3)|(((B)&0xF8)>>3))))
-   int x, y,j=0;
-
-  for(; h-- ;)
-  {
-    for(x = 0; x < w*3 ; x += 6)
-    {
-	if ((++j)*2<w*h){
-		u32 data=(((u32)gp2x_video_RGB_color16( srcs[x+3], srcs[x+4], srcs[x+5] ) )<< 16) |
-				   (u16)gp2x_video_RGB_color16( srcs[x+0], srcs[x+1], srcs[x+2] );
-			   *dest_screen32++=data;
-			   *dest_screen32++=data;
-		
-	 	}
-    }
-    srcs += 2048;
-  }  
-	}
+   }
+ }
  else
  {
    for (; h-- > 0; dest += pitch, srcs += 1024)
